/*
 ****************************************************
 ******          File: CFlav2Main.js           ******
 ******                                        ******
 ******             Version: 2.1.3             ******
 ****************************************************
*/

/*
Portions  Copyright 2005 Apple Computer, Inc. All rights reserved.
	and
Remainder  Copyright 2018 James R. Macak. All rights reserved.
*/


/*
 *****************************************************
 ******         GLOBAL VARIABLES FOLLOW         ******
 *****************************************************
*/

var scrollbar;
var scrollArea;
var front;
var back;
var req = new XMLHttpRequest();
var storedateMonthly;
var gettingMonthlyError;
var finalProcessedMonthlyText;
var procMonthlyDoneTime = 0;


/*
 *****************************************************
 ******        PARSE THE DOWNLOADED TEXT        ******
 *****************************************************
*/

function processMonthly(theText) {
	"use strict";

	var tempText = theText.slice(((theText.search(/centered">\s\s+<h5>/)) + 10), (theText.search(/<div class="wrap">/)));

		tempText = tempText.replace(/<p>|<\/p>/g, "");
		tempText = "<p>" + tempText;
		tempText = tempText.replace(/<div class="wrap todays.+>/g, "\r</p>\r<p>\r");
		tempText = tempText.replace(/<div class="grid grid-centered">|<div class="col-3">|<div class="circle flavor-circle">|<img src.+>|<\/div>/g, "");
		tempText = tempText.replace(/<span class="ribbon flavor-of-day">/g, "<br><span class=\"flavNameMonthly\">");
		tempText = tempText.replace(/<\/span>/g, "</span><br>");
		tempText = tempText.replace(/\s\s+/g, "\r");

	if ((tempText.search(/<div class="row">/)) != -1) {
		var firstMonth = tempText.slice(0, (tempText.search(/<div class="row">/)));
		var secondMonth = tempText.slice(tempText.search(/[0-9]<\/a>\s<\/p>/)+6);
		tempText = firstMonth + secondMonth;
	}
	
	tempText = tempText.replace(/<h5>/g, "<span class=\"dateMonthly\">");
	tempText = tempText.replace(/<\/h5>/g, "</span>");
	
	finalProcessedMonthlyText = tempText + "</p>";

	var now = new Date();
	procMonthlyDoneTime = now.getTime();

	document.getElementById("statusMonthly").innerHTML = "";
	document.getElementById("textMonthly").innerHTML = finalProcessedMonthlyText;
	
	scrollArea.refresh();
}


/*
 *****************************************************
 ******      LISTENS FOR WEBSITE RESPONSE,      ******
 ******       & ACTS ON SUCCESS OR ERROR        ******
 *****************************************************
*/

function processReqChange() {
	"use strict";
	
	if (req.readyState == 4) {
		if (req.status == 200) {
			var theText = req.responseText;
			processMonthly(theText);
			
		} else {
			gettingMonthlyError = true;
			var theTime = new Date();
			var errorMsg1M = "Oops! Error getting data.<br>";
			var errorMsg2M = "The retrieval of the Flavor Forecast data from the server failed on " + theTime.toLocaleString() + ".<br>";
			var errorMsg3M = "Will retry when widget is viewed again.<br>";
			var errorMsg4M = "If your Internet connection is OK, repeated errors are likely due to a problem with the remote server.";
			var monthlyErrorTime = theTime.getTime();
			var monthlyTimeDiff = monthlyErrorTime - procMonthlyDoneTime;
				
			if (monthlyTimeDiff > 432000000) {
				document.getElementById("errMonthly5").innerHTML = "";
				document.getElementById("textMonthlyErr").innerHTML = "";
				document.getElementById("errMonthly1").innerHTML = errorMsg1M;
				document.getElementById("errMonthly2").innerHTML = errorMsg2M;
				document.getElementById("errMonthly3").innerHTML = errorMsg3M;
				document.getElementById("errMonthly4").innerHTML = errorMsg4M;
				
				scrollArea.refresh();
				storedateMonthly = "";
					
// LEAVE THE FOLLOWING ALERT INTACT! THIS WILL BE WRITTEN TO A CONSOLE APP LOG
				alert("There was a problem retrieving Flavor Forecast data in the Custard Flavors widget via XMLHttpRequest(). The req.status was " + req.status + ".");
					
			} else {
				var errorMsg5M = "<strong> Please note: </strong>Although there was an error in retrieving new Flavor Forecast data, the previously saved Flavor Forecast is presented below.";
				document.getElementById("errMonthly1").innerHTML = errorMsg1M;
				document.getElementById("errMonthly2").innerHTML = errorMsg2M;
				document.getElementById("errMonthly3").innerHTML = errorMsg3M;
				document.getElementById("errMonthly4").innerHTML = errorMsg4M;
				document.getElementById("errMonthly5").innerHTML = errorMsg5M;
				document.getElementById("textMonthlyErr").innerHTML = finalProcessedMonthlyText; //2.0d21 addition
				
				scrollArea.refresh();
				storedateMonthly = "";

// LEAVE THE FOLLOWING ALERT INTACT! THIS WILL BE WRITTEN TO A CONSOLE APP LOG
				alert("There was a problem retrieving Flavor Forecast data in the Custard Flavors widget via XMLHttpRequest(). The req.status was " + req.status + ".");
			}
		}
    }
}


/*
 *****************************************************
 ******      REQUEST DATA FROM THE WEBSITE      ******
 *****************************************************
*/

function loadXMLDoc() {
	"use strict";

	if(req) {
		req.onreadystatechange = processReqChange;
		
		document.getElementById("textMonthly").innerHTML = "";
		document.getElementById("statusMonthly").innerHTML = "Getting flavor forecast info...";

		var theURL = "https://www.kopps.com/flavor-preview";
		req.open("GET", theURL, true);
		req.setRequestHeader("Cache-Control", "no-cache");
		req.send("");
	}
}


/*
 ******************************************************
 ******   RESET PRIOR ERROR (IF ONE OCCURRED)    ******
 ******    REQUEST DATA ANEW FROM THE WEBSITE    ******
 ******************************************************
*/

function loadMonthly() {
	"use strict";

	if (gettingMonthlyError) {
		document.getElementById("errMonthly5").innerHTML = "";
		document.getElementById("errMonthly1").innerHTML = "";
		document.getElementById("errMonthly2").innerHTML = "";
		document.getElementById("errMonthly3").innerHTML = "";
		document.getElementById("errMonthly4").innerHTML = "";
		document.getElementById("textMonthlyErr").innerHTML = "";

		gettingMonthlyError = false;
	}

	loadXMLDoc();
}


/*
 *****************************************************
 ******      CONTROLS WHEN WE GET NEW DATA      ******
 ******   (ALSO OFF/ON SWITCH FOR BETA VERS.)   ******
 *****************************************************
*/

function onShow() {
	"use strict";

	var now = new Date();
	var nowString = String(now);
	var nowdate = nowString.substring(0,15);
	if (storedateMonthly != nowdate) {
		storedateMonthly = nowdate;
		loadMonthly();
	}
}


/*
 *****************************************************
 ******       SHOW THE BACK OF THE WIDGET       ******
 *****************************************************
*/

function showPrefs() {
	"use strict";
	
	front = document.getElementById("front");
	back = document.getElementById("back");
    
    if (window.widget) {
        widget.prepareForTransition("ToBack");
    }
        
    front.style.display="none";
    back.style.display="block";
    
    if (window.widget) {
        setTimeout ("widget.performTransition();", 0);
    }
}


/*
 ******************************************************
 ******       SHOW THE FRONT OF THE WIDGET       ******
 ******************************************************
*/

function hidePrefs() {
	"use strict";

	front = document.getElementById("front");
	back = document.getElementById("back");
    
    if (window.widget) {
        widget.prepareForTransition("ToFront");
    }
    back.style.display="none";
    front.style.display="block";
    
    if (window.widget) {
        setTimeout ("widget.performTransition();", 0);
    }
}


/*
 ****************************************************
 ******          SETUP FOR THE WIDGET          ******
 ****************************************************
*/

function loaded() {
	"use strict";

	scrollbar = new AppleVerticalScrollbar(document.getElementById("myScrollBar"));
	scrollArea = new AppleScrollArea(document.getElementById("parentDiv"), scrollbar);
	scrollArea.scrollsHorizontally = false;
	scrollArea.singlepressScrollPixels = 15;
	scrollArea.focus();
	
	window.onfocus = function () { scrollArea.focus(); }
	window.onblur = function () { scrollArea.blur(); }

	var gDoneButton = new AppleGlassButton(document.getElementById("doneButton"), "Y u m !", hidePrefs);
    var gInfoButton = new AppleInfoButton(document.getElementById("infoButton"), document.getElementById("front"), "black", "black", showPrefs);

	var newContent = document.getElementById("monthly");
	scrollArea.reveal(newContent);
	scrollArea.refresh();
	
	onShow();
}


/*
 ****************************************************
 ******      WAKES UP WIDGET WHEN SHOWN      ******
 ****************************************************
*/

if (window.widget) {
	widget.onshow = onShow;
}
